@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 
-from .field import AttrField, BaseField, ElementField, HtmlField, RegexField, TextField
+from .exceptions import IgnoreThisItem
+from .field import (AttrField, BaseField, ElementField, HtmlField, RegexField,
+                    TextField)
 from .item import Item
 from .middleware import Middleware
 from .request import Request
 from .response import Response
 from .spider import Spider
-from .exceptions import IgnoreThisItem
 
-__version__ = "0.6.6"
+__version__ = "0.6.9"
