@@ -108,7 +108,7 @@ class Spider(SpiderHook):
     # Default values passing to each request object. Not implemented yet.
     headers: dict = None
     metadata: dict = None
-    kwargs: dict = None
+    aiohttp_kwargs: dict = None
 
     # Some fields for statistics
     failed_counts: int = 0
@@ -153,7 +153,7 @@ class Spider(SpiderHook):
         self.request_config = self.request_config or {}
         self.headers = self.headers or {}
         self.metadata = self.metadata or {}
-        self.kwargs = self.kwargs or {}
+        self.aiohttp_kwargs = self.aiohttp_kwargs or {}
         self.spider_kwargs = spider_kwargs
         self.request_config = self.request_config or {}
         self.request_session = ClientSession()
@@ -176,14 +176,6 @@ class Spider(SpiderHook):
         # semaphore, used for concurrency control
         self.sem = asyncio.Semaphore(self.concurrency)
 
-    async def _cancel_tasks(self):
-        tasks = []
-        for task in asyncio.Task.all_tasks():
-            if task is not asyncio.tasks.Task.current_task():
-                tasks.append(task)
-                task.cancel()
-        await asyncio.gather(*tasks, return_exceptions=True)
-
     async def _process_async_callback(
         self, callback_results: AsyncGeneratorType, response: Response = None
     ):
@@ -297,7 +289,7 @@ class Spider(SpiderHook):
         after_start=None,
         before_stop=None,
         cancel_tasks: bool = True,
-        **kwargs,
+        **spider_kwargs,
     ):
         """
         Start an async spider
@@ -306,7 +298,7 @@ class Spider(SpiderHook):
         :param after_start: hook
         :param before_stop: hook
         :param cancel_tasks: cancel async tasks
-        :param kwargs: Additional keyword args to initialize spider
+        :param spider_kwargs: Additional keyword args to initialize spider
         :return: An instance of :cls:`Spider`
         """
         loop = loop or asyncio.get_event_loop()
@@ -315,12 +307,25 @@ class Spider(SpiderHook):
             loop=loop,
             is_async_start=True,
             cancel_tasks=cancel_tasks,
-            **kwargs,
+            **spider_kwargs,
         )
         await spider_ins._start(after_start=after_start, before_stop=before_stop)
 
         return spider_ins
 
+    @staticmethod
+    async def cancel_all_tasks():
+        """
+        Cancel all tasks
+        :return:
+        """
+        tasks = []
+        for task in asyncio.Task.all_tasks():
+            if task is not asyncio.tasks.Task.current_task():
+                tasks.append(task)
+                task.cancel()
+        await asyncio.gather(*tasks, return_exceptions=True)
+
     @classmethod
     def start(
         cls,
@@ -355,7 +360,9 @@ class Spider(SpiderHook):
         return spider_ins
 
     async def handle_callback(self, aws_callback: typing.Coroutine, response):
-        """Process coroutine callback function"""
+        """
+        Process coroutine callback function
+        """
         callback_result = None
 
         try:
@@ -393,7 +400,9 @@ class Spider(SpiderHook):
         return callback_result, response
 
     async def multiple_request(self, urls, is_gather=False, **kwargs):
-        """For crawling multiple urls"""
+        """
+        For crawling multiple urls
+        """
         if is_gather:
             resp_results = await asyncio.gather(
                 *[self.handle_request(self.request(url=url, **kwargs)) for url in urls],
@@ -437,9 +446,21 @@ class Spider(SpiderHook):
         metadata: dict = None,
         request_config: dict = None,
         request_session=None,
-        **kwargs,
+        **aiohttp_kwargs,
     ):
-        """Init a Request class for crawling html"""
+        """
+        Init a Request class for crawling html
+        :param url:
+        :param method:
+        :param callback:
+        :param encoding:
+        :param headers:
+        :param metadata:
+        :param request_config:
+        :param request_session:
+        :param aiohttp_kwargs:
+        :return:
+        """
         headers = headers or {}
         metadata = metadata or {}
         request_config = request_config or {}
@@ -447,7 +468,7 @@ class Spider(SpiderHook):
 
         headers.update(self.headers.copy())
         request_config.update(self.request_config.copy())
-        kwargs.update(self.kwargs.copy())
+        aiohttp_kwargs.update(self.aiohttp_kwargs.copy())
 
         return Request(
             url=url,
@@ -458,11 +479,13 @@ class Spider(SpiderHook):
             metadata=metadata,
             request_config=request_config,
             request_session=request_session,
-            **kwargs,
+            **aiohttp_kwargs,
         )
 
     async def start_master(self):
-        """Actually start crawling."""
+        """
+        Actually start crawling
+        """
         async for request_ins in self.process_start_urls():
             self.request_queue.put_nowait(self.handle_request(request_ins))
         workers = [
@@ -477,9 +500,13 @@ class Spider(SpiderHook):
             await self.stop(SIGINT)
         else:
             if self.cancel_tasks:
-                await self._cancel_tasks()
+                await self.cancel_all_tasks()
 
     async def start_worker(self):
+        """
+        Stark spider worker
+        :return:
+        """
         while True:
             request_item = await self.request_queue.get()
             self.worker_tasks.append(request_item)
@@ -504,5 +531,5 @@ class Spider(SpiderHook):
         :return:
         """
         self.logger.info(f"Stopping spider: {self.name}")
-        await self._cancel_tasks()
+        await self.cancel_all_tasks()
         self.loop.stop()
